@@ -70,8 +70,8 @@ class Quality:
         max_difference = np.max(differences)
 
         if min_difference <= 0 or max_difference >= 24:
-            invalid.append(('time step difference x 1e3', (round(min_difference*1000),
-                                                           round(max_difference*1000)), '0, 24'))
+            invalid.append(('time step difference x 1e5', (round(min_difference*1e5),
+                                                           round(max_difference*1e5)), '0, 24'))
             self.n_data_test_failures += 1
         return invalid
 
